@@ -1,3 +1,19 @@
+"""Representations of a downloaded NCBI Datasets Package.
+
+NCBI Datasets provides data in ZipArchives for Genome, Gene, Pathogen and Virus resources.
+These classes each contain dataset catalogs that help programmatically determine
+the file contents.
+
+Examples:
+    A quickstart is to download a package, and then create a generic `Dataset` wrapper:
+
+    >>> from ncbi.datasets.package.dataset import get_dataset_from_file
+
+    package = get_dataset_from_file(path_to_file)
+    for report in package.get_data_reports():
+        # do something with the protobuf report object
+
+"""
 import contextlib
 import json
 import logging
